package com.ruoyi.project.business.mapper.quotation;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TqSalespersonSetPrice;
import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-21
 */
public interface TqSalespersonSetPriceMapper extends BaseMapper<TqSalespersonSetPrice> {

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TqSalespersonSetPrice selectTqSalespersonSetPriceById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tqSalespersonSetPrice 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TqSalespersonSetPrice> selectTqSalespersonSetPriceList(TqSalespersonSetPrice tqSalespersonSetPrice);

    /**
     * 新增【请填写功能名称】
     *
     * @param tqSalespersonSetPrice 【请填写功能名称】
     * @return 结果
     */
    public int insertTqSalespersonSetPrice(TqSalespersonSetPrice tqSalespersonSetPrice);

    /**
     * 修改【请填写功能名称】
     *
     * @param tqSalespersonSetPrice 【请填写功能名称】
     * @return 结果
     */
    public int updateTqSalespersonSetPrice(TqSalespersonSetPrice tqSalespersonSetPrice);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTqSalespersonSetPriceById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTqSalespersonSetPriceByIds(Long[] ids);
}
