package com.ruoyi.project.business.controller.quotation;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.business.domain.TqSalespersonSetPrice;
import com.ruoyi.project.business.service.quotation.ITqSalespersonSetPriceService;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2024-05-21
 */
@RestController
@RequestMapping("/business/price/set")
public class TqSalespersonSetPriceController extends BaseController {

    @Autowired
    private ITqSalespersonSetPriceService tqSalespersonSetPriceService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:price:list')")
    @GetMapping("/list")
    public TableDataInfo list(TqSalespersonSetPrice tqSalespersonSetPrice) {
        startPage();
        List<TqSalespersonSetPrice> list = tqSalespersonSetPriceService.selectTqSalespersonSetPriceList(
            tqSalespersonSetPrice);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:price:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TqSalespersonSetPrice tqSalespersonSetPrice) {
        List<TqSalespersonSetPrice> list = tqSalespersonSetPriceService.selectTqSalespersonSetPriceList(
            tqSalespersonSetPrice);
        ExcelUtil<TqSalespersonSetPrice> util = new ExcelUtil<TqSalespersonSetPrice>(TqSalespersonSetPrice.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:price:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tqSalespersonSetPriceService.selectTqSalespersonSetPriceById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TqSalespersonSetPrice tqSalespersonSetPrice) {
        return toAjax(tqSalespersonSetPriceService.insertTqSalespersonSetPrice(tqSalespersonSetPrice));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TqSalespersonSetPrice tqSalespersonSetPrice) {
        return toAjax(tqSalespersonSetPriceService.updateTqSalespersonSetPrice(tqSalespersonSetPrice));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:price:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tqSalespersonSetPriceService.deleteTqSalespersonSetPriceByIds(ids));
    }
}
